#
# spec file for package python-shaptools
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

%if 0%{?suse_version} < 1500
%bcond_with test
%else
%bcond_without test
%endif

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-shaptools
Version:        0.3.12+git.1619007514.1951d23
Release:        lp152.2.9.1
Summary:        Python tools to interact with SAP HANA utilities
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/SUSE/shaptools
Source:         %{name}-%{version}.tar.gz
%if %{with test}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest}
%endif
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
API to expose SAP HANA functionalities

%prep
%setup -q -n %{name}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# do not install tests
%python_expand rm -r %{buildroot}%{$python_sitelib}/tests
%python_clone -a %{buildroot}%{_bindir}/shapcli

%post
%python_install_alternative shapcli

%postun
%python_uninstall_alternative shapcli

%if %{with test}
%check
%pytest tests
%endif

%files %{python_files}
%if 0%{?sle_version:1} && 0%{?sle_version} < 120300
%doc README.md LICENSE
%else
%doc README.md
%license LICENSE
%endif
%{python_sitelib}/*
%python_alternative %{_bindir}/shapcli

%changelog
* Fri Mar 12 2021 Xabier Arbulu <xarbulu@suse.com>
- Create version 0.3.12
- Fix the HANA sidadm user creation to transform to lowercase
  properly
  (bsc#1185090)
* Tue Feb  9 2021 Xabier Arbulu <xarbulu@suse.com>
- Fix spec file to build properly the shapcli executable
* Thu Sep 24 2020 Xabier Arbulu <xarbulu@suse.com>
- Create version 0.3.11
- Add new functionalities to know the currently installed ENSA
  version for Netweaver (only for ASCS and ERS instances)
  (jsc#SLE-4047)
* Thu Sep  3 2020 Xabier Arbulu <xarbulu@suse.com>
- Create version 0.3.10
- Fix how HANA database is started and stopped to work in multi
  host environment. sapcontrol commands are used instead of HDB
  now
  (jsc#SLE-4047)
* Tue Aug 25 2020 Xabier Arbulu <xarbulu@suse.com>
- Create version 0.3.9
- Fix issue when secondary registration fails after a successful
  SSFS files copy process. Now the registration return code will
  be checked in the new call (bsc#1175709)
* Fri Mar 27 2020 Simranpal Singh <simranpal.singh@suse.com>
- Create version 0.3.8
- Add functionality to extract SAP sar files using SAPCAR tool
  (jsc#SLE-10902, jsc#SLE-10903, jsc#ECO-817, jsc#ECO-818)
* Tue Mar 24 2020 Xabier Arbulu <xarbulu@suse.com>
- Create version 0.3.7
- Improve hana installation software detection to allow more use
  cases
* Thu Mar 19 2020 Xabier Arbulu <xarbulu@suse.com>
- Create version 0.3.6
- Change the get_platform method to include the system OS type
* Thu Jan  2 2020 Simranpal Singh <simranpal.singh@suse.com>
- Create package version 0.3.5
- Add function to install HANA with XML passwords file
- Add functionality to update XML passwords file
* Thu Dec  5 2019 Xabier Arbulu <xarbulu@suse.com>
- Create package version 0.3.4
- Fix ascs restart conditions in ers installation
* Thu Nov  7 2019 Simranpal Singh <simranpal.singh@suse.com>
- Create package version 0.3.3
- Add update_conf_file for Netweaver
* Tue Oct 22 2019 Xabier Arbulu <xarbulu@suse.com>
- Create package version 0.3.2
- Add isconnected and reconnect methods
* Wed Aug  7 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Add the required code to install SAP Netweaver instances
  * Wrap sapcontrol command usage
  * Install and uninstall SAP instances
  * Check current installation status
* Tue Jul 23 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.3.1
- Add support for Power machines
  (jsc#SLE-4031, jsc#SLE-4143, boo#1137989)
* Thu Jul 18 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Add an option to run the commands in remote nodes to shapcli
* Wed Jul 17 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.3.0
- shapcli is provided to expose shaptools api methods as command line tool
* Tue Jun 11 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.2.1 with fixed spec files. Now the package
  is available from SLE12-SP2 to SLE15 versions
  (jsc#SLE-4031, jsc#SLE-4143, boo#1137989)
* Tue Jun  4 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.2.0 with the latest changes
* Wed May 29 2019 Ayoub Belarbi (abelarbi@suse.com)
- Update hdb connector to return metadata besides the query
  records.
* Thu May 16 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Update SR registration process. Now the methods retries the
  registration command until a successful return and copies the
  SSFS files from the primary node as well
* Tue Apr 23 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Remove enum34 dependency from code
* Wed Mar  6 2019 dakechi@suse.com
- Fix the package license to be in synch with repo license.
* Mon Mar  4 2019 xarbulu@suse.com
- Improved the use of keystore access. When the key_name is informed,
  the user_name/user_password is not needed.
* Mon Feb 25 2019 dakechi@suse.com
- Fix UT to check the inst formatting correctly
- Move the comment to the right place
- Enforce the HANA instance nr format.
- Forces Intance nr always with 2 positions filled with 0
- Forces right formating on HANA OS admin user.
* Thu Dec 20 2018 xarbulu@suse.com
- First package version
